@@ -1,4 +1,4 @@
-//@line 39 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-miramar/mail/base/content/aboutDialog.js"
+//@line 39 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/aboutDialog.js"
 
 // Services = object with smart getters for common XPCOM services
 Components.utils.import("resource://gre/modules/Services.jsm");
@@ -38,11 +38,15 @@ function init(aEvent)
     document.getElementById("version").value += " (" + buildDate + ")";
   }
 
-//@line 79 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-miramar/mail/base/content/aboutDialog.js"
+//@line 79 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/aboutDialog.js"
   gAppUpdater = new appUpdater();
-//@line 81 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-miramar/mail/base/content/aboutDialog.js"
+//@line 81 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/aboutDialog.js"
 
-//@line 87 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-miramar/mail/base/content/aboutDialog.js"
+  let defaults = Services.prefs.getDefaultBranch("");
+  let channelLabel = document.getElementById("currentChannel");
+  channelLabel.value = defaults.getCharPref("app.update.channel");
+
+//@line 91 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/aboutDialog.js"
 }
 
 // This function is used to open about: tabs. The caller should ensure the url
@@ -79,7 +83,7 @@ function openUILink(url, event)
   }
 }
 
-//@line 124 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-miramar/mail/base/content/aboutDialog.js"
+//@line 128 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/aboutDialog.js"
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
 Components.utils.import("resource://gre/modules/AddonManager.jsm");
